==> jffnms_0.7.9.orig.tar.gz: jffnms-0.7.9/engine/consolidate.php <==
<?
/* Integrator
 * Copyright (C) <2002> Javier Szyszlican <javier@szysz.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

    $jffnms_functions_include="engine";
    include_once("../conf/config.php");
    
    $total_run_time = 60; //60 seconds
    $interval = 15; //15 seconds interval between runs

    if (!$times) $times = $_SERVER["argv"][1];
    if (empty($times)) $times = 3;

    $i = 0;
    $date_start = time();

    if (is_process_running(NULL,2) === false) {	//check if a process named as myself is already running (one instance is me)

	logger ("Consolidator Starting...\n");
	do {
	    $aux_start = time();
	    $i++;    

	    //FIXME replace this calls with functions
	    include("consolidate/syslog.php"); flush();
	    include("consolidate/tacacs.php"); flush();	
	    include("consolidate/traps.php"); flush();
	    include("consolidate/events.php"); flush();
	    include("consolidate/events_latest.php"); flush();
	    include("consolidate/alarms.php"); flush();
    
	    $run_time = time() - $aux_start;

	    logger ("Partial time: $run_time sec.\n");

	    if ($i < $times) sleep($interval);
	    $time_elapsed = time() - $date_start;
	    logger ("Elapsed time $time_elapsed sec.\n");
	} while (($i < $times) && ($time_elapsed < $total_run_time)); 

	$time_total = time() - $date_start;
        logger("Total time: $time_total sec.\n");

    } else
	logger ("Another instance of Consolidator is running, aborting...\n");

    db_close();
?>

==> jffnms_0.8.1.orig.tar.gz: jffnms-0.8.1/engine/consolidate.php <==
<?
/* Consolidator. This file is part of JFFNMS
 * Copyright (C) <2002> Javier Szyszlican <javier@szysz.com>
 * This program is licensed under the GNU GPL, full terms in the LICENSE file
 */

    $jffnms_functions_include="engine";
    include_once("../conf/config.php");
    
    $total_run_time = 60; //60 seconds
    $interval = 15; //15 seconds interval between runs

    if (!isset($times)) $times = $_SERVER["argv"][1];
    if (empty($times)) $times = 3;

    $i = 0;
    $date_start = time();

    if (is_process_running(NULL,2) === false) {	//check if a process named as myself is already running (one instance is me)

	detach();

	logger ("Consolidator Starting...\n");
	do {
	    $aux_start = time();
	    $i++;    

	    //FIXME replace this calls with functions
	    include("consolidate/syslog.php"); flush();
	    include("consolidate/tacacs.php"); flush();	
	    include("consolidate/traps.php"); flush();
	    include("consolidate/events.php"); flush();
	    include("consolidate/events_latest.php"); flush();
	    include("consolidate/alarms.php"); flush();
    
	    $run_time = time() - $aux_start;

	    logger ("Partial time: $run_time sec.\n");

	    if ($i < $times) sleep($interval);
	    $time_elapsed = time() - $date_start;
	    logger ("Elapsed time $time_elapsed sec.\n");
	} while (($i < $times) && ($time_elapsed < $total_run_time)); 

	$time_total = time() - $date_start;
        logger("Total time: $time_total sec.\n");

    } else
	logger ("Another instance of Consolidator is running, aborting...\n");

    db_close();
?>
